<?php
/**
 * Implement Custom Header functionality
 */

/**
 * Set up the WordPress core custom header settings.
 */
function aa_custom_header_setup() {
	/**
	 * @param array $args {
	 *     An array of custom-header support arguments.
	 *
	 *     @type bool   $header_text            Whether to display custom header text. Default false.
	 *     @type int    $width                  Width in pixels of the custom header image. Default 1260.
	 *     @type int    $height                 Height in pixels of the custom header image. Default 240.
	 *     @type bool   $flex_height            Whether to allow flexible-height header images. Default true.
	 *     @type string $admin_head_callback    Callback function used to style the image displayed in
	 *                                          the Appearance > Header screen.
	 *     @type string $admin_preview_callback Callback function used to create the custom header markup in
	 *                                          the Appearance > Header screen.
	 * }
	 */
	add_theme_support( 'custom-header', apply_filters( 'aa_custom_header_args', array(
		'default-text-color'     => 'fff',
		'width'                  => 1170,
		'height'                 => 400,
		'flex-height'            => true,
		'wp-head-callback'       => 'aa_header_style',
		'admin-head-callback'    => 'aa_admin_header_style',
		'admin-preview-callback' => 'aa_admin_header_image',
	) ) );
}

if ( ! function_exists( 'aa_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 * @see aa_custom_header_setup().
 */
function aa_header_style() {
	$text_color = get_header_textcolor();

	// If no custom color for text is set, let's bail.
	if ( display_header_text() && $text_color === get_theme_support( 'custom-header', 'default-text-color' ) )
		return;

	// If we get this far, we have custom styles.
	?>
	<style type="text/css" id="aa-header-css">
	<?php
		// Has the text been hidden?
		if ( ! display_header_text() ) :
	?>
		.site-title,
		.site-description {
			clip: rect(1px 1px 1px 1px); /* IE7 */
			clip: rect(1px, 1px, 1px, 1px);
			position: absolute;
		}
		.title-group { background: transparent; }
	<?php
		// If the user has set a custom color for the text, use that.
		elseif ( $text_color != get_theme_support( 'custom-header', 'default-text-color' ) ) :
			/*
	?>
		.site-title a {
			color: #<?php echo esc_attr( $text_color ); ?>;
		}
	<?php */ endif; ?>
	</style>
	<?php
}
endif; // aa_header_style


if ( ! function_exists( 'aa_admin_header_style' ) ) :
/**
 * Style the header image displayed on the Appearance > Header screen.
 * @see aa_custom_header_setup()
 */
function aa_admin_header_style() {
	$maincol = get_theme_option('col1');
	$dark10  = darken($maincol, 10);
?>
	<link type="text/css" rel="stylesheet" href="//fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,700,300italic,400italic,700italic|Lora:400,700,400italic,700italic">
	<style type="text/css" id="aa-admin-header-css">
	#testata {
	  margin: 0;
	  margin-left: -15px;
	  margin-right: -15px;
	  padding: 0;
	  position: relative;
	  border-top: 1px solid #eeeeee;
	  max-width: 1170px;
	}
	@media (min-width: 768px) {
	  #testata {
	    min-height: 200px;
	  }
	}
	#testata #blog-info {
	  background-color: transparent;
	  position: absolute;
	  top: 0;
	  height: 100%;
	  width: 100%;
	  text-align: center;
	}
	#testata img {
	  width: 100%;
	  height: auto;
	}
	#testata span {
	  margin: 24px 12px;
	  line-height: 1em;
	  padding: 0;
	  display: block;
	}

	.table {
	  display: table;
	  height: 100%;
	  width: 100%;
	}

	.table-cell {
	  display: table-cell;
	  vertical-align: middle;
	}

	.title-group {
	  background-color: rgba(255, 255, 255, 0.9);
	  padding: 12px;
	  display: inline-block;
	  font-family: "Source Sans Pro","Helvetica Neue","Helvetica","Arial",sans-serif;
	}
	h1, h2 { font-weight: 500 }

	.site-title {
	  font-size: 64px;
	  line-height: 1em;
	  margin-top: 0;
	  margin-bottom: 12px;
	  padding: 0;
	}
	@media (max-width: 768px) {
	  .site-title {
	    font-size: 32px;
	  }
	}
	.site-title a { color: <?php echo $maincol; ?>; text-decoration: none }
	.site-title a:hover { color: <?php echo $dark10; ?>; text-decoration: underline; }

	.site-description {
	  margin: 0;
	  font-size: 32px !important;
	  line-height: 1em;
	}
	@media (max-width: 768px) {
	  .site-description {
	    font-size: 16px;
	  }
	}
	tr.displaying-header-text {
		height: 0; overflow: hidden; opacity: 0;
		clip: rect(1px 1px 1px 1px); /* IE7 */
		clip: rect(1px, 1px, 1px, 1px);
		position: absolute;
	}
	</style>
<?php
}
endif; // aa_admin_header_style

if ( ! function_exists( 'aa_admin_header_image' ) ) :
/**
 * Create the custom header image markup displayed on the Appearance > Header screen.
 * @see aa_custom_header_setup()
 */
function aa_admin_header_image() {
?>
	<div id="testata">
		<?php if ( get_header_image() ) : ?>
			<img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="sfondo testata" />
		<?php endif; ?>
		<div id="blog-info">
			<div class="table">
				<div class="table-cell">
					<div class="title-group displaying-header-text">
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
						<h2 class="site-description"><?php bloginfo( 'description' ); ?></h2>
					</div>
				</div>
			</div>
		</div>
	</div>
<?php
}
endif; // aa_admin_header_image
